@@ -4,7 +4,7 @@
 #
 # Released under the MIT license.
 
-from time import strptime
+from datetime import datetime
 from json import loads
 import requests
 from bs4 import BeautifulSoup
@@ -100,4 +100,8 @@ def get_eq_info():
     url = "https://api.p2pquake.net/v2/jma/quake?limit=1"
     r = requests.get(url)
     ql = loads(r.text)
-    return ql[0]["earthquake"]["hypocenter"]
\ No newline at end of file
+    dt = ql[0]["created_at"]
+    dto = datetime.strptime(ql[0]["created_at"].split(".")[0], "%Y/%m/%d %H:%M:%S")
+    retd = ql[0]["earthquake"]["hypocenter"]
+    retd["datetime"] = dto
+    return retd
\ No newline at end of file
